==> flutter_catalogue_widgets-0.0.15.tar.gz: lib/custom-appBar.dart <==
/*
Description:
Creates an AppBar for the page. Has a title and various icon buttons which can be used for routing

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-appBar.dart';

Usage:
-Creating the object for the appbar

AppBarParameters paramobject = new AppBarParameters(elevation: 5, bottomOpacity: 1.0, toolbarOpacity: 1.0, titleSpacing: 1.0, centerTitle: true);
    List<Widget> appBarIcons = [
      IconButton(
        icon:  Icon(Icons.search),
        onPressed: () {},
      ),
      IconButton(
        icon:  Icon(Icons.help),
        onPressed: () {},
      ),
      IconButton(
        icon:  Icon(Icons.verified_user),
        onPressed: () {},
      ),
    ];

    -Object call for the widget
     appBar:customAppBar(appBarIcons,paramobject)

    Author:
    Karan Arora
*/




import 'package:flutter/material.dart';
import 'theme.dart';
import 'package:flutter_catalogue_widgets/consts.dart' as cons;
import 'package:flutter_catalogue_widgets/widget-classesUsed.dart';

Widget customAppBar(List<Widget> prod, AppBarParameters param) {
  if (param == null) {
    return AppBar(
      automaticallyImplyLeading: cons.automaticallyImplyLeading,
      iconTheme: mediumGreyThemeData().iconTheme,
      leading: null,
      elevation: cons.elevationFive,
      centerTitle: cons.centerTitle,
      backgroundColor: mediumGreyThemeData().scaffoldBackgroundColor,
      toolbarOpacity: cons.toolbarOpacityOne,
      bottomOpacity: cons.bottomOpacityOne,
      titleSpacing: cons.tileSpacingOne,
      title: cons.title,
      actions: cons.action,
      textTheme: mediumGreyThemeData().textTheme,
      shape: null,
      brightness: cons.brightness,
      actionsIconTheme: mediumGreyThemeData().iconTheme,
      primary: cons.primary,
      flexibleSpace: null,
      bottom: null,
    );
  } else {
    if (param.bottom != null) {
      return AppBar(
        automaticallyImplyLeading: (param.automaticallyImplyLeading != null) ? param.automaticallyImplyLeading : cons.automaticallyImplyLeading,
          iconTheme: (param.iconTheme != null)? param.iconTheme : mediumGreyThemeData().iconTheme,
          leading: (param.leading != null) ? param.leading : null,
          elevation:
              (param.elevation != null) ? param.elevation : cons.elevationFive,
          centerTitle: (param.centerTitle != null)
              ? param.centerTitle
              : cons.centerTitle,
          backgroundColor: (param.backgroundColor != null)
              ? param.backgroundColor
              : mediumGreyThemeData().scaffoldBackgroundColor,
          toolbarOpacity: (param.toolbarOpacity != null)
              ? param.toolbarOpacity
              : cons.toolbarOpacityOne,
          bottomOpacity: (param.bottomOpacity != null)
              ? param.bottomOpacity
              : cons.bottomOpacityOne,
          titleSpacing: (param.titleSpacing != null)
              ? param.titleSpacing
              : cons.tileSpacingOne,
          title: (param.title != null) ? param.title : cons.title,
          actions: prod,
          bottom: param.bottom,
          flexibleSpace: (param.flexibleSpace != null) ? param.flexibleSpace : null,
          primary: (param.primary != null) ? param.primary : cons.primary,
          actionsIconTheme: (param.actionsIconTheme != null) ? param.actionsIconTheme : mediumGreyThemeData().iconTheme,
          brightness: (param.brightness != null) ? param.brightness : cons.brightness,
          shape: (param.shape != null) ? param.shape : null,
          textTheme: (param.textTheme != null) ? param.textTheme : mediumGreyThemeData().textTheme);
    } else {
      return AppBar(
          automaticallyImplyLeading: (param.automaticallyImplyLeading != null) ? param.automaticallyImplyLeading : cons.automaticallyImplyLeading,
        iconTheme: (param.iconTheme != null) ? param.iconTheme : mediumGreyThemeData().iconTheme,
          leading: (param.leading != null) ? param.leading : null,
          elevation:
              (param.elevation != null) ? param.elevation : cons.elevationFive,
          centerTitle: (param.centerTitle != null)
              ? param.centerTitle
              : cons.centerTitle,
          backgroundColor: (param.backgroundColor != null)
              ? param.backgroundColor
              : mediumGreyThemeData().scaffoldBackgroundColor,
          toolbarOpacity: (param.toolbarOpacity != null)
              ? param.toolbarOpacity
              : cons.toolbarOpacityOne,
          bottomOpacity: (param.bottomOpacity != null)
              ? param.bottomOpacity
              : cons.bottomOpacityOne,
          titleSpacing: (param.titleSpacing != null)
              ? param.titleSpacing
              : cons.tileSpacingOne,
          title: (param.title != null) ? param.title : cons.title,
          actions: prod,
          shape: (param.shape != null) ? param.shape : null,
          brightness: (param.brightness != null) ? param.brightness : cons.brightness,
          actionsIconTheme: (param.actionsIconTheme != null) ? param.actionsIconTheme : mediumGreyThemeData().iconTheme,
          primary: (param.primary != null) ? param.primary : cons.primary,
          bottom: null,
          flexibleSpace: (param.flexibleSpace != null) ? param.flexibleSpace : null,
          textTheme: (param.textTheme != null) ? param.textTheme : mediumGreyThemeData().textTheme);
    }
  }
}

==> flutter_catalogue_widgets-0.0.16.tar.gz: lib/custom-appBar.dart <==
/*
Description:
Creates an AppBar for the page. Has a title and various icon buttons which can be used for routing

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'package:flutter_catalogue_widgets/custom-appBar.dart';

Usage:
-Creating the object for the appbar

AppBarParameters paramobject = new AppBarParameters(elevation: 5, bottomOpacity: 1.0, toolbarOpacity: 1.0, titleSpacing: 1.0, centerTitle: true);
    List<Widget> appBarIcons = [
      IconButton(
        icon:  Icon(Icons.search),
        onPressed: () {},
      ),
      IconButton(
        icon:  Icon(Icons.help),
        onPressed: () {},
      ),
      IconButton(
        icon:  Icon(Icons.verified_user),
        onPressed: () {},
      ),
    ];

    -Object call for the widget
     appBar:customAppBar(appBarIcons,paramobject)

    Author:
    Karan Arora
*/




import 'package:flutter/material.dart';
import 'package:flutter_catalogue_widgets/theme.dart';
import 'package:flutter_catalogue_widgets/consts.dart' as cons;
import 'package:flutter_catalogue_widgets/widget-classesUsed.dart';

Widget customAppBar(List<Widget> prod, AppBarParameters param) {
  if (param == null) {
    return AppBar(
      automaticallyImplyLeading: cons.automaticallyImplyLeading,
      iconTheme: mediumGreyThemeData().iconTheme,
      leading: null,
      elevation: cons.elevationFive,
      centerTitle: cons.centerTitle,
      backgroundColor: mediumGreyThemeData().scaffoldBackgroundColor,
      toolbarOpacity: cons.toolbarOpacityOne,
      bottomOpacity: cons.bottomOpacityOne,
      titleSpacing: cons.tileSpacingOne,
      title: cons.title,
      actions: cons.action,
      textTheme: mediumGreyThemeData().textTheme,
      shape: null,
      brightness: cons.brightness,
      actionsIconTheme: mediumGreyThemeData().iconTheme,
      primary: cons.primary,
      flexibleSpace: null,
      bottom: null,
    );
  } else {
    if (param.bottom != null) {
      return AppBar(
        automaticallyImplyLeading: (param.automaticallyImplyLeading != null) ? param.automaticallyImplyLeading : cons.automaticallyImplyLeading,
          iconTheme: (param.iconTheme != null)? param.iconTheme : mediumGreyThemeData().iconTheme,
          leading: (param.leading != null) ? param.leading : null,
          elevation:
              (param.elevation != null) ? param.elevation : cons.elevationFive,
          centerTitle: (param.centerTitle != null)
              ? param.centerTitle
              : cons.centerTitle,
          backgroundColor: (param.backgroundColor != null)
              ? param.backgroundColor
              : mediumGreyThemeData().scaffoldBackgroundColor,
          toolbarOpacity: (param.toolbarOpacity != null)
              ? param.toolbarOpacity
              : cons.toolbarOpacityOne,
          bottomOpacity: (param.bottomOpacity != null)
              ? param.bottomOpacity
              : cons.bottomOpacityOne,
          titleSpacing: (param.titleSpacing != null)
              ? param.titleSpacing
              : cons.tileSpacingOne,
          title: (param.title != null) ? param.title : cons.title,
          actions: prod,
          bottom: param.bottom,
          flexibleSpace: (param.flexibleSpace != null) ? param.flexibleSpace : null,
          primary: (param.primary != null) ? param.primary : cons.primary,
          actionsIconTheme: (param.actionsIconTheme != null) ? param.actionsIconTheme : mediumGreyThemeData().iconTheme,
          brightness: (param.brightness != null) ? param.brightness : cons.brightness,
          shape: (param.shape != null) ? param.shape : null,
          textTheme: (param.textTheme != null) ? param.textTheme : mediumGreyThemeData().textTheme);
    } else {
      return AppBar(
          automaticallyImplyLeading: (param.automaticallyImplyLeading != null) ? param.automaticallyImplyLeading : cons.automaticallyImplyLeading,
        iconTheme: (param.iconTheme != null) ? param.iconTheme : mediumGreyThemeData().iconTheme,
          leading: (param.leading != null) ? param.leading : null,
          elevation:
              (param.elevation != null) ? param.elevation : cons.elevationFive,
          centerTitle: (param.centerTitle != null)
              ? param.centerTitle
              : cons.centerTitle,
          backgroundColor: (param.backgroundColor != null)
              ? param.backgroundColor
              : mediumGreyThemeData().scaffoldBackgroundColor,
          toolbarOpacity: (param.toolbarOpacity != null)
              ? param.toolbarOpacity
              : cons.toolbarOpacityOne,
          bottomOpacity: (param.bottomOpacity != null)
              ? param.bottomOpacity
              : cons.bottomOpacityOne,
          titleSpacing: (param.titleSpacing != null)
              ? param.titleSpacing
              : cons.tileSpacingOne,
          title: (param.title != null) ? param.title : cons.title,
          actions: prod,
          shape: (param.shape != null) ? param.shape : null,
          brightness: (param.brightness != null) ? param.brightness : cons.brightness,
          actionsIconTheme: (param.actionsIconTheme != null) ? param.actionsIconTheme : mediumGreyThemeData().iconTheme,
          primary: (param.primary != null) ? param.primary : cons.primary,
          bottom: null,
          flexibleSpace: (param.flexibleSpace != null) ? param.flexibleSpace : null,
          textTheme: (param.textTheme != null) ? param.textTheme : mediumGreyThemeData().textTheme);
    }
  }
}
